@@ -5,8 +5,8 @@
 import json
 from typing import Union, Callable, Dict, ClassVar
 
-__all__ = ('Jata', 'JataAttributeError', 'MutableDefault', 'asdict')
-__version__ = '1.1'
+__all__ = ('Jata', 'JataAttributeError', 'MutableDefault', 'asdict', 'data')
+__version__ = '1.2'
 
 ALLOWED_TYPES = (str, int, float, bool, list, dict, type(None))
 
@@ -118,22 +118,7 @@ class Jata(metaclass=JataMeta):
         except KeyError:
             raise JataAttributeError(key)
 
-        def convert_jata_list(jata_list: list):
-            def convert(item):
-                if isinstance(item, dict):
-                    return Jata(item)
-                elif isinstance(item, list):
-                    convert_jata_list(item)
-                return item
-
-            jata_list[:] = [convert(item) for item in jata_list]
-
-        if isinstance(attr, dict):
-            return Jata(attr)
-        elif isinstance(attr, list):
-            convert_jata_list(attr)
-
-        return attr
+        return _convert(attr)
 
     def __setattr__(self, key, value):
         if key == Jata._Jata_DATA_FIELD_NAME:
@@ -156,6 +141,35 @@ class Jata(metaclass=JataMeta):
         return f"{self.__class__.__name__}({data_repr})"
 
 
+def _convert(attr):
+    def convert_jata_list(jata_list: list):
+        def convert(item):
+            if isinstance(item, dict):
+                return Jata(item)
+            elif isinstance(item, list):
+                convert_jata_list(item)
+            return item
+
+        jata_list[:] = [convert(item) for item in jata_list]
+
+    if isinstance(attr, dict):
+        return Jata(attr)
+    elif isinstance(attr, list):
+        convert_jata_list(attr)
+
+    return attr
+
+
+def data(jata: Union[Jata, dict]) -> dict:
+    """
+    Converts to dict where values are Jata
+    """
+    if isinstance(jata, Jata):
+        # noinspection PyProtectedMember
+        jata = jata._Jata_data
+    return {key: _convert(value) for key, value in jata.items()}
+
+
 def asdict(jata: Union[Jata, dict]):
     """
     Converts to a regular python dict
